import { ICertificate } from '@aws-cdk/aws-certificatemanager';
import { IVpc } from '@aws-cdk/aws-ec2';
import { BaseService, Cluster, ContainerImage, ICluster, LogDriver, Secret } from '@aws-cdk/aws-ecs';
import { ApplicationListener, ApplicationTargetGroup, BaseLoadBalancer, NetworkListener, NetworkTargetGroup } from '@aws-cdk/aws-elasticloadbalancingv2';
import { IRole } from '@aws-cdk/aws-iam';
import { IHostedZone } from '@aws-cdk/aws-route53';
import cdk = require('@aws-cdk/core');
export declare enum LoadBalancerType {
    APPLICATION = 0,
    NETWORK = 1
}
/**
 * The properties for the base LoadBalancedEc2Service or LoadBalancedFargateService service.
 */
export interface LoadBalancedServiceBaseProps {
    /**
     * The name of the cluster that hosts the service.
     *
     * You can only specify either vpc or cluster. Alternatively, you can leave both blank.
     * @default - create a new cluster; if you do not specify a cluster nor a vpc, a new VPC will be created for you as well.
     */
    readonly cluster?: ICluster;
    /**
     * The VPC where the ECS instances will be running or the ENIs will be deployed.
     *
     * You can only specify either vpc or cluster. Alternatively, you can leave both blank.
     * @default - uses the vpc defined in the cluster or creates a new one.
     */
    readonly vpc?: IVpc;
    /**
     * The image used to start a container.
     */
    readonly image: ContainerImage;
    /**
     * The port number on the container that is bound to the user-specified or automatically assigned host port.
     *
     * If you are using containers in a task with the awsvpc or host network mode, exposed ports should be specified using containerPort.
     * If you are using containers in a task with the bridge network mode and you specify a container port and not a host port,
     * your container automatically receives a host port in the ephemeral port range.
     *
     * For more information, see hostPort.
     * Port mappings that are automatically assigned in this way do not count toward the 100 reserved ports limit of a container instance.
     *
     * @default 80
     */
    readonly containerPort?: number;
    /**
     * Determines whether the Load Balancer will be internet-facing.
     *
     * @default true
     */
    readonly publicLoadBalancer?: boolean;
    /**
     * The desired number of instantiations of the task definition to keep running on the service.
     *
     * @default 1
     */
    readonly desiredCount?: number;
    /**
     * The type of the load balancer to be used.
     *
     * @default application
     */
    readonly loadBalancerType?: LoadBalancerType;
    /**
     * Certificate Manager certificate to associate with the load balancer.
     * Setting this option will set the load balancer port to 443.
     *
     * @default - No certificate associated with the load balancer.
     */
    readonly certificate?: ICertificate;
    /**
     * The environment variables to pass to the container.
     *
     * @default - No environment variables.
     */
    readonly environment?: {
        [key: string]: string;
    };
    /**
     * The secret environment variables to pass to the container
     *
     * @default - No secret environment variables.
     */
    readonly secrets?: {
        [key: string]: Secret;
    };
    /**
     * Flag to indicate whether to enable logging.
     *
     * @default true
     */
    readonly enableLogging?: boolean;
    /**
     * Determines whether the Service will be assigned a public IP address.
     *
     * @default false
     */
    readonly publicTasks?: boolean;
    /**
     * Domain name for the service, e.g. api.example.com
     *
     * @default - No domain name.
     */
    readonly domainName?: string;
    /**
     * Route53 hosted zone for the domain, e.g. "example.com."
     *
     * @default - No Route53 hosted domain zone.
     */
    readonly domainZone?: IHostedZone;
    /**
     * Override for the Fargate Task Definition execution role
     *
     * @default - No value
     */
    readonly executionRole?: IRole;
    /**
     * The name of the IAM role that grants containers in the task permission to call AWS APIs on your behalf.
     *
     * @default - A task role is automatically created for you.
     */
    readonly taskRole?: IRole;
    /**
     * The container name value to be specified in the task definition.
     *
     * @default - none
     */
    readonly containerName?: string;
    /**
     * The name of the service.
     *
     * @default - CloudFormation-generated name.
     */
    readonly serviceName?: string;
    /**
     * The LogDriver to use for logging.
     *
     * @default - AwsLogDriver if enableLogging is true
     */
    readonly logDriver?: LogDriver;
    /**
     * The period of time, in seconds, that the Amazon ECS service scheduler ignores unhealthy
     * Elastic Load Balancing target health checks after a task has first started.
     *
     * @default - defaults to 60 seconds if at least one load balancer is in-use and it is not already set
     */
    readonly healthCheckGracePeriod?: cdk.Duration;
}
/**
 * The base class for LoadBalancedEc2Service and LoadBalancedFargateService services.
 */
export declare abstract class LoadBalancedServiceBase extends cdk.Construct {
    readonly assignPublicIp: boolean;
    /**
     * The desired number of instantiations of the task definition to keep running on the service.
     */
    readonly desiredCount: number;
    readonly loadBalancerType: LoadBalancerType;
    readonly loadBalancer: BaseLoadBalancer;
    readonly listener: ApplicationListener | NetworkListener;
    readonly targetGroup: ApplicationTargetGroup | NetworkTargetGroup;
    /**
     * The cluster that hosts the service.
     */
    readonly cluster: ICluster;
    readonly logDriver?: LogDriver;
    /**
     * Constructs a new instance of the LoadBalancedServiceBase class.
     */
    constructor(scope: cdk.Construct, id: string, props: LoadBalancedServiceBaseProps);
    protected getDefaultCluster(scope: cdk.Construct, vpc?: IVpc): Cluster;
    protected addServiceAsTarget(service: BaseService): void;
    private createAWSLogDriver;
}
